@@ -979,19 +979,22 @@ init_page(void)
 #define	S_ISDIR(m)	(((m) & S_IFMT) == S_IFDIR)
 #endif
 
-static char *tmp_dvi_name = NULL; /* name of backup file for useTempFp */
+static char *m_tmp_dvi_name = NULL; /* name of backup file for useTempFp */
 
 /* access function for backup file name */
 char *get_tmp_dvi_name() {
-    return tmp_dvi_name;
+    return m_tmp_dvi_name;
 }
 
 static void
 remove_tmp_dvi_file(void *dummy)
 {
     UNUSED(dummy);
-    if (tmp_dvi_name != NULL)
-	unlink(tmp_dvi_name);
+    if (m_tmp_dvi_name != NULL) {
+	unlink(m_tmp_dvi_name);
+	free(m_tmp_dvi_name);
+    }
+    m_tmp_dvi_name = NULL;
 }
 
 
@@ -1004,26 +1007,27 @@ make_backup_fp(FILE *source_fp, FILE *target_fp)
 #if !HAVE_FTRUNCATE
     /* in this case, we can't use ftruncate() on the existing temp file -
        just close the existing one, and set flag to open a new one */
-    if (tmp_dvi_name != NULL)
-	unlink(tmp_dvi_name);
+    remove_tmp_dvi_file(NULL);
     if (target_fp != NULL)
 	fclose(target_fp);
     /* make sure we use a new temp file, else we'd have a race condition
        after closing it */
-    free(tmp_dvi_name);
-    tmp_dvi_name = NULL;
     first_time = True;
 #endif
     
     if (first_time) { /* doesn't exist yet, create it */
-	if ((tmp_fd = xdvi_temp_fd(&tmp_dvi_name)) == -1) {
+	if ((tmp_fd = xdvi_temp_fd(&m_tmp_dvi_name)) == -1) {
 	    XDVI_ERROR((stderr, "error creating temporary file - disabling `useTempFp'."));
+	    resource.use_temp_fp = False;
+	    remove_tmp_dvi_file(NULL);
 	    return NULL;
 	}
-	/* 	fprintf(stderr, "temporary file name: |%s|, %d\n", tmp_dvi_name, tmp_fd); */
-	TRACE_EVENTS((stderr, "Created temp file: |%s|\n", tmp_dvi_name));
+	/* 	fprintf(stderr, "temporary file name: |%s|, %d\n", m_tmp_dvi_name, tmp_fd); */
+	TRACE_EVENTS((stderr, "Created temp file: |%s|\n", m_tmp_dvi_name));
 	if ((target_fp = try_fdopen(tmp_fd, "wb+")) == NULL) {
 	    XDVI_ERROR((stderr, "error opening temporary file (%s) - disabling `useTempFp'.", strerror(errno)));
+	    resource.use_temp_fp = False;
+	    remove_tmp_dvi_file(NULL);
 	    return NULL;
 	}
 	first_time = False;
@@ -1032,12 +1036,14 @@ make_backup_fp(FILE *source_fp, FILE *target_fp)
 	      and position both files at beginning */
 	ASSERT(target_fp != NULL, "");
 	ASSERT(source_fp != NULL, "");
-	
+
 #if HAVE_FTRUNCATE
 	if (ftruncate(tmp_fd, 0) < 0) {
-	    XDVI_ERROR((stderr, "Couldn't truncate file %s: %s - disabling `useTempFp'.",
-			tmp_dvi_name, strerror(errno)));
-	    unlink(tmp_dvi_name);
+		
+	    XDVI_ERROR((stderr, "Couldn't truncate file %s: %s - disabling `useTempFp'; target_fp: %p.",
+			m_tmp_dvi_name, strerror(errno), target_fp));
+	    resource.use_temp_fp = False;
+	    remove_tmp_dvi_file(NULL);
 	    fclose(target_fp);
 	    return NULL;
 	}
@@ -1052,12 +1058,16 @@ make_backup_fp(FILE *source_fp, FILE *target_fp)
 		    "Error creating temporary file: %s\n"
 		    "- disabling `useTempFp'.",
 		    strerror(errno)));
+	remove_tmp_dvi_file(NULL);
+	resource.use_temp_fp = False;
 	fclose(target_fp);
 	target_fp = NULL;
     }
     
     /* rewind both files, else DVI parsing will fail! */
-    fflush(target_fp);
+    if (target_fp != NULL) {
+	fflush(target_fp);
+    }
     fseek(source_fp, 0L, SEEK_SET);
     if (target_fp != NULL) {
 	fseek(target_fp, 0L, SEEK_SET);
