@@ -18,7 +18,7 @@
  * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
  * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-*/
+ */
 
 /*
   List of recently visited files, initialized from X resource
@@ -30,6 +30,7 @@
 #include "xdvi-config.h"
 #include "xdvi.h"
 #include "util.h"
+#include "dl_list.h"
 #include "my-snprintf.h"
 #include "string-utils.h"
 #include "dvi-init.h"
@@ -117,7 +118,7 @@ file_history_init(void)
 	    pageno = 0;
 	}
 	else {
-	    while (isspace(*ptr))
+	    while (isspace((int)*ptr))
 		ptr++;
 	}
 
@@ -358,7 +359,6 @@ file_history_open(const char *fname)
 	    
 	    globals.ev.flags |= EV_NEWDOC;
 	    globals.ev.flags |= EV_FILEHIST_GOTO_PAGE;
-	    globals.ev.flags |= EV_PAGEHIST_INSERT;
 	}
 	else { /* re-open old file */
 	    popup_message(globals.widgets.top_level,
@@ -375,7 +375,6 @@ file_history_open(const char *fname)
 	    filehist_menu_refresh();
 	    
 	    if (!internal_open_dvi(globals.dvi_name, &errflag, True)) {
-/*  		|| !internal_init_dvi(&errflag, True)) { */
 		popup_message(globals.widgets.top_level,
 			      MSG_ERR,
 			      NULL,
