@@ -56,6 +56,14 @@
 #include "topic-window.h"
 #include "help-window.h"
 
+/* missing features that will be listed in the help window */
+#if !XDVI_XT_TIMER_HACK
+#define HAVE_MISSING_FEATURES 1
+#endif
+
+#if !HAVE_REGEX_H
+#define HAVE_MISSING_FEATURES 1
+#endif
 
 /*
  * The number of help topics - must larger or equal to actual number of items,
@@ -81,8 +89,8 @@ create_help_text(Widget parent, const char *name, const char *value)
     XtSetArg(args[n], XmNeditMode, XmMULTI_LINE_EDIT);		n++;
     XtSetArg(args[n], XmNwordWrap, True);			n++;
     XtSetArg(args[n], XmNtopAttachment, XmATTACH_FORM);		n++;
-/*     XtSetArg(args[n], XmNtopWidget, top_widget);		n++; */
-/*     XtSetArg(args[n], XmNtopOffset, 10);			n++; */
+    /*     XtSetArg(args[n], XmNtopWidget, top_widget);		n++; */
+    /*     XtSetArg(args[n], XmNtopOffset, 10);			n++; */
     XtSetArg(args[n], XmNleftAttachment, XmATTACH_FORM);	n++;
     XtSetArg(args[n], XmNrightAttachment, XmATTACH_FORM);	n++;
     XtSetArg(args[n], XmNbottomAttachment, XmATTACH_FORM);	n++;
@@ -317,6 +325,18 @@ initialize_items(struct topic_info *info)
 #ifdef USE_GF
 	"- gf file support enabled\n",
 #endif
+#if HAVE_MISSING_FEATURES
+	"\n",
+	"Features not available on this platform:\n",
+#if !XDVI_XT_TIMER_HACK
+	"- Could not redefine XtAppAddTimeOut(); some widgets may\n",
+	"  not be updated until the mouse is moved.\n",
+#endif
+#if !HAVE_REGEX_H
+	"- regex.h header not available, regular expression support\n",
+	"  in string search is disabled.\n",
+#endif
+#endif /* HAVE_MISSING_FEATURES */
 	NULL
     };
 
@@ -512,7 +532,7 @@ initialize_items(struct topic_info *info)
 #else
 	"\n",
 #endif
-	"     Makes the fonts lighter (by substracting from the gamma\n",
+	"     Makes the fonts lighter (by subtracting from the gamma\n",
 	"     value).\n",
 	"\n",
 	NULL
@@ -577,7 +597,7 @@ initialize_items(struct topic_info *info)
 	"     to the history item after the deleted one. With a prefix\n",
 	"     argument n, delete n next history items.\n",
 	"\n",
-	"n or f or Space or Return or LineFeed or PgDn",
+	"n or f or Return or LineFeed or PgDn",
 #if MOTIF
 	", toolbar button 5\n",
 #else
@@ -586,7 +606,10 @@ initialize_items(struct topic_info *info)
 	"     Moves to the next page (or to the nth next page if a\n",
 	"     number is given).\n",
 	"\n",
-	"p or b or Ctrl-h or BackSpace or Del or PgUp",
+	"Space key\n",
+	"     Moves down or to the next page.",
+	"\n",
+	"p or b or Ctrl-h or BackSpace or PgUp",
 #if MOTIF
 	", toolbar button 4\n",
 #else
@@ -594,6 +617,9 @@ initialize_items(struct topic_info *info)
 #endif
 	"     Moves to the previous page (or back n pages).\n",
 	"\n",
+	"Del key\n",
+	"     Moves up on the page or to the previous page.",
+	"\n",
 	"Up-arrow\n",
 	"     Scrolls page up.\n",
 	"\n",
@@ -1019,7 +1045,7 @@ show_help(Widget toplevel, const char *topic)
 	info.ok_callback = NULL;
 	info.cancel_callback = NULL;
 	info.items = items;
-/* 	info.items_size = NUM_HELP_TOPICS; */
+	/* 	info.items_size = NUM_HELP_TOPICS; */
 	    
 	help_shell = create_topic_window(toplevel,
 					 "xdvik: Help",
