@@ -35,11 +35,12 @@
 #include <limits.h>
 #include "c-openmx.h"
 
+#include "xdvi.h"
+
 #ifdef MOTIF
 #include <Xm/Xm.h>
 #endif
 
-#include "xdvi.h"
 #include "events.h"
 #include "dvi-draw.h"
 #include "dvi-init.h"
@@ -82,6 +83,35 @@ static int mag_conv_y = 0;
 static Position new_mag_x = 0;
 static Position new_mag_y = 0;
 
+
+/* default magnifier dimensions */
+static struct mg_size_rec {
+    int w;
+    int h;
+} mg_size[] = {
+    {200, 150}, {400, 250}, {700, 500}, {1000, 800}, {1200, 1200}
+};
+
+size_t get_magglass_items(void) {
+    return XtNumber(mg_size);
+}
+
+int get_magglass_width(int idx) {
+    return mg_size[idx].w;
+}
+
+int get_magglass_height(int idx) {
+    return mg_size[idx].h;
+}
+
+void set_magglass_widht(int idx, int w) {
+    mg_size[idx].w = w;
+}
+
+void set_magglass_height(int idx, int h) {
+    mg_size[idx].h = h;
+}
+
 static void
 can_exposures(struct WindowRec *windowrec)
 {
@@ -133,20 +163,20 @@ mag_release(XEvent * event)
 	      over a hyperlink).
 
 	      Forcing a redraw with
-	         redraw(&mane);
+	      redraw(&mane);
 	      may cause a `BadDrawable' X error with color material (e.g. from #702288),
 	      or a `draw_part: shouldn't happen: POST encountered' error. Neither do
 	      the following work:
-	         globals.ev.flags |= EV_EXPOSE;		(doesn't fix the bug)
-		 draw_page();			(same effect as redraw(&mane))
-		 globals.ev.flags |= EV_NEWPAGE;	(works, but is crude and causes flicker)
+	      globals.ev.flags |= EV_EXPOSE;		(doesn't fix the bug)
+	      draw_page();			(same effect as redraw(&mane))
+	      globals.ev.flags |= EV_NEWPAGE;	(works, but is crude and causes flicker)
 		 
 	      So I decided to use expose() for the time being, which 
 	      sets mane.min_x to the current x point (which doesn't happen
 	      with EV_EXPOSE; this causes the test for `mane.min_x < MAXDIM'
 	      to fail in events.c; look for `see comment in mag.c').
 	    */
-/*  	    fprintf(stderr, "========triggering expose!\n"); */
+	    /*  	    fprintf(stderr, "========triggering expose!\n"); */
 	    expose(&mane, event->xbutton.x_root, event->xbutton.y_root, 10, 10);
 	}
     }
@@ -219,10 +249,8 @@ draw_ticks(unsigned int width, unsigned int height, GC ourGC)
        The user can select the units via a resource (e.g. XDvi*tickUnits: bp),
        or a command-line option (e.g. -xrm '*tickUnits: cm').  The length of
        the ticks can be controlled by a resource (e.g. XDvi*tickLength: 10), or
-       a command-line option (e.g. -xrm '*tickLength: 10000').  If the tick
-       length exceeds the popup window size, then a graph-paper grid is drawn
-       over the whole window.  Zero, or negative, tick length completely
-       suppresses rulers. */
+       a command-line option (e.g. -xrm '*tickLength: 10000').  Zero, or negative,
+       tick length completely suppresses rulers. */
 
     pixels_per_tick = (double)resource.pixels_per_inch;
     if (strcmp(resource.tick_units, "pt") == 0)
@@ -394,8 +422,8 @@ do_movemag(int x, int y)
     compute_mag_pos(&xx, &yy);
     XMoveWindow(DISP, magnifier.win, xx, yy);
     scroll_window(&magnifier,
-		 (x + mane_base_x) * mane.shrinkfactor - (int)magnifier.width / 2,
-		 (y + mane_base_y) * mane.shrinkfactor - (int)magnifier.height / 2);
+		  (x + mane_base_x) * mane.shrinkfactor - (int)magnifier.width / 2,
+		  (y + mane_base_y) * mane.shrinkfactor - (int)magnifier.height / 2);
     draw_ticks(magnifier.width, magnifier.height, globals.gc.ruler);
 }
 
@@ -707,7 +735,7 @@ Act_magnifier(Widget w, XEvent *event,
 	  HACK ALERT: we can arrive here after loading a new file via the file selector
 	  for which not all fonts have been generated. In that case, dereferencing
 	  bg_current would bomb. Try to recover by simply returning here.
-	 */
+	*/
 	return;
     }
 
@@ -856,5 +884,5 @@ XtActionsRec mag_actions[] = {
 void
 create_magnifier(void)
 {
-    XtAppAddActions(app, mag_actions, XtNumber(mag_actions));
+    XtAppAddActions(globals.app, mag_actions, XtNumber(mag_actions));
 }
