@@ -793,6 +793,19 @@ create_search_window(struct search_settings *settings)
     translation_str = NULL;
 #endif /* not MOTIF */
     
+    translation_str = get_string_va(
+#ifdef MOTIF
+				    "<Key>osfCancel:cancel-search(%p)\n"
+#else
+				    "<Key>Escape:cancel-search(%p)\n"
+#endif
+				    "<Key>Return:do-search(%p)\n"
+				    "Ctrl<Key>g:find-next()",
+				    (void *)settings, (void *)settings);
+    
+    xlats = XtParseTranslationTable(translation_str);
+    free(translation_str);
+
     top_level_shell = XtVaCreatePopupShell("find_popup",
 					   SHELL_WIDGET,
 					   globals.widgets.top_level,
@@ -877,7 +890,7 @@ create_search_window(struct search_settings *settings)
 
     {
 	Widget textfield = NULL;
-	Widget grab_shell;
+	Widget grab_shell = NULL;
 	size_t n;
 	XmStringTable items;
 	
@@ -940,9 +953,11 @@ create_search_window(struct search_settings *settings)
 	XtAddCallback(textfield, XmNactivateCallback, cb_search_get_term, settings);
 	XtAddCallback(searchbox_input, XmNselectionCallback, cb_search_history_select, (XtPointer)settings);
 
+	XtOverrideTranslations(textfield, xlats);
 	/* workaround for pointer grabbing bug (see xm_menu.c) */
-	if (get_widget_by_name(&grab_shell, searchbox_input, "GrabShell", True))
+	if (get_widget_by_name(&grab_shell, searchbox_input, "GrabShell", True)) {
 	    XtAddCallback(grab_shell, XtNpopdownCallback, popdown_callback, NULL);
+	}
 	
     }
 #else /* defined(MOTIF) && USE_COMBOBOX */
@@ -1251,19 +1266,6 @@ create_search_window(struct search_settings *settings)
     XtAddCallback(cancel_button, ACTIVATE_CALLBACK_NAME, cb_search_cancel, settings);
     XtAddCallback(find_button, ACTIVATE_CALLBACK_NAME, cb_search_get_term_button, settings);
 
-    translation_str = get_string_va(
-#ifdef MOTIF
-				    "<Key>osfCancel:cancel-search(%p)\n"
-#else
-				    "<Key>Escape:cancel-search(%p)\n"
-#endif
-				    "<Key>Return:do-search(%p)\n"
-				    "Ctrl<Key>g:find-next()",
-				    (void *)settings, (void *)settings);
-    
-    xlats = XtParseTranslationTable(translation_str);
-    free(translation_str);
-
     XtOverrideTranslations(searchbox_form, xlats);
     XtOverrideTranslations(options_left_form, xlats);
     XtOverrideTranslations(options_right_form, xlats);
