@@ -1300,8 +1300,11 @@ htex_scan_anchor(const char *cp, size_t len)
 	}
 	return False;
     }
-    else { /* not a start tag */
-	MYTRACE((stderr, "Xdvi warning: skipping malformed hyperref special `%s'", cp));
+    else { /* unrecognized tag */
+	if (globals.warn_spec_now) {
+	    XDVI_WARNING((stderr, "Ignoring unknown hyperref special `%s'", cp));
+	}
+	return False;
     }
     return get_href_depth(&stack);
 }
