@@ -199,7 +199,9 @@ page_history_show_statusline(struct dl_list *head,
 	}
 	
 	if (head == curr) {
-	    ASSERT(m_page_history_currpos == n + 1, "Consistency check for pagelist position failed!");
+	    xdvi_assert(XDVI_VERSION_INFO, __FILE__, __LINE__,
+			m_page_history_currpos == n + 1,
+			"%d == %d + 1", m_page_history_currpos, n);
 	    sprintf(ptr, " [%d]", item->pageno + 1);
 	    ptr += 3 + length_of_int(item->pageno + 1);
 	}
