@@ -142,6 +142,42 @@ extern void *realloc();
 
 #define BUF_SIZE 1024
 
+void
+xdvi_assert(const char *version,
+	    const char *filename,
+	    int lineno,
+	    Boolean condition,
+	    const char *fmt, ...)
+{
+    if (!(condition)) {
+	fprintf(stderr,
+		"\n************************************************************\n"
+		"XDvi %s: Failed assertion:\n%s:%d: ",
+		version, filename, lineno);
+	va_list argp;
+	va_start(argp, fmt);
+	(void)vfprintf(stderr, fmt, argp);
+	va_end(argp);
+#ifdef NDEBUG
+	fprintf(stderr,
+		"\nAborting now. Please report this as a bug to:\n"
+		"http://sourceforge.net/tracker/?group_id=23164&atid=377580\n"
+		"If a core dump has been produced, please invoke:\n"
+		"gdb %s core\nThen type \"bt\", "
+		"and include the resulting output in your bug report.\n"
+ 		"************************************************************\n",
+		globals.program_name);
+	do_abort();
+#else
+	fprintf(stderr,
+		"\nPlease report this as a bug to:\n"
+		"http://sourceforge.net/tracker/?group_id=23164&atid=377580\n"
+ 		"************************************************************\n");
+#endif
+    }
+}
+
+
 void
 xdvi_bell(void)
 {
@@ -1743,6 +1779,82 @@ iconv_convert_string(const char *from_enc, const char *to_enc, const char *str)
 #endif /* HAVE_ICONV_H */
 }
 
+
+/* Replace (pseudo-)format arguments in NULL-terminated argv list as follows:
+ * %f -> filename, %l -> linenumber, %c -> column number.
+ * If %f or %l are not specified, they are appended as %f and +%l.
+ * If colno == 0, no %c argument is provided.
+ */
+char **
+src_format_arguments(char **argv, const char *filename, int lineno, int colno)
+{
+    size_t i;
+    Boolean found_filename = False;
+    Boolean found_lineno = False;
+    
+    for (i = 0; argv[i] != NULL; i++) {
+	char *ptr, *curr = argv[i];
+	while ((ptr = strchr(curr, '%')) != NULL) {
+	    char *p1;
+	    if ((p1 = strchr("flc", ptr[1])) != NULL) { /* we have a formatting char */
+		char digit_arg[LENGTH_OF_INT];
+		const char *new_elem = NULL;
+		/* remember offsets and lengths */
+		size_t l_init = ptr - argv[i];
+		size_t l_rest = strlen(ptr + 2) + 1;
+		size_t l_mid;
+		
+		if (*p1 == 'f') {
+		    found_filename = True;
+		    new_elem = filename;
+		}
+		else if (*p1 == 'l') {
+		    found_lineno = True;
+		    sprintf(digit_arg, "%d", lineno);
+		    new_elem = digit_arg;
+		}
+		else if (*p1 == 'c') {
+		    sprintf(digit_arg, "%d", colno);
+		    new_elem = digit_arg;
+		}
+		
+		l_mid = strlen(new_elem);
+		
+		argv[i] = xrealloc(argv[i], strlen(argv[i]) + l_mid + 1);
+		curr = argv[i] + l_init; /* need to reinitialize it because of realloc */
+		memmove(curr + l_mid, curr + 2, l_rest);
+		memcpy(curr, new_elem, l_mid);
+		curr += l_mid;
+	    }
+	    else if (ptr[1] == '%') { /* escaped %, skip both */
+		curr = ptr + 2;
+	    }
+	    else {
+		curr = ptr + 1;
+	    }
+	}
+    }
+
+    /* append line number and file name arguments if they were not specified */
+    if (!found_lineno) {
+	i++;
+	argv = xrealloc(argv, (i + 1) * sizeof *argv);
+	argv[i - 1] = xmalloc(LENGTH_OF_INT + 2);
+	sprintf(argv[i - 1], "+%d", lineno);
+	argv[i] = NULL;
+    }
+    
+    if (!found_filename) {
+	i++;
+	argv = xrealloc(argv, (i + 1) * sizeof *argv);
+	argv[i - 1] = xstrdup(filename);
+	argv[i] = NULL;
+    }
+
+    return argv;
+}
+
+
 #if 0
 /*
  * Search integer array <arr> of length <arr_len> for for <item>.
