@@ -54,7 +54,12 @@ int try_open(const char *fname, int flags);
 int try_open_mode(const char *fname, int flags, mode_t mode);
 
 extern int xdvi_temp_fd(char **tempfilename);
-
+extern void xdvi_assert(const char *version,
+			const char *filename,
+			int lineno,
+			Boolean condition,
+			const char *fmt,
+			...);
 
 typedef void (*child_exited_proc)(int status, struct xchild *this);
 
@@ -119,6 +124,7 @@ extern unsigned long parse_debugging_option(const char *ptr);
 extern int get_avg_font_width(XFontStruct *font);
 extern char **split_line(const char *line, char sep, size_t begin, size_t end, size_t *ret_items);
 extern char *find_file(const char *filename, struct stat *statbuf, kpse_file_format_type pathinfo);
+extern char **src_format_arguments(char **argv, const char *filename, int lineno, int colno);
 
 /*
   hashtable wrapper functions, mostly used by dvi-draw.c to
