@@ -64,7 +64,7 @@ read_VF_index(struct font *fontp, wide_bool hushcs)
     long checksum;
     struct macro *newmacro;
     unsigned long maxcc = 0;
-    Boolean dummy = False;
+    Boolean dummy_success = False;
     
     fontp->read_char = NULL;
     fontp->flags |= FONT_VIRTUAL;
@@ -93,7 +93,7 @@ read_VF_index(struct font *fontp, wide_bool hushcs)
 					    VF_file, cmnd, fontp,
 					    fontp->vf_table, VFTABLELEN,
 					    &fontp->vf_chain,
-					    &dummy);
+					    &dummy_success);
 	if (fontp->first_font == NULL)
 	    fontp->first_font = newfontp;
     }
@@ -160,8 +160,8 @@ read_VF_index(struct font *fontp, wide_bool hushcs)
 	    m->end = m->pos + len;
 	}
 	if (globals.debug & DBG_PK)
-	     printf("Read VF macro for character %lu; dy = %ld, length = %d\n",
-		    cc, m->dvi_adv, len);
+	    printf("Read VF macro for character %lu; dy = %ld, length = %d\n",
+		   cc, m->dvi_adv, len);
     }
     if (cmnd != POST)
 	XDVI_FATAL((stderr, "Wrong command byte found in VF macro list:  %d", cmnd));
