@@ -86,7 +86,7 @@ scroll_page_if_needed(int x_min, int x_max, int y_min, int y_max)
     /* check if we need to scroll vertically; first, down for y_min */
     test_scroll = y_min + drawing_y - clip_h;
     if ((resource.expert_mode & XPRT_SHOW_STATUSLINE) != 0)
-	test_scroll += global_statusline_h;
+	test_scroll += get_statusline_height();
 
     TRACE_SRC((stderr, "test_scroll vertically: %d", test_scroll));
 #if DEBUG_SCROLL_IF_NEEDED
@@ -473,11 +473,16 @@ synthetisize_event(XEvent *ev, Widget button)
 int xm_get_height(Widget w)
 {
     int ret_h = 0;
-    static Arg args = { XtNheight, (XtArgVal)0 };
+    static Dimension h0, h1, h2;
+    static Arg args[] = {
+	{XmNheight, (XtArgVal) &h0},
+	{XmNmarginHeight, (XtArgVal) &h1},
+	{XmNshadowThickness, (XtArgVal) &h2},
+    };
     ASSERT(w != NULL, "widget in xm_get_width mustn't be NULL!");
 
-    args.value = (XtArgVal)&ret_h;
-    XtGetValues(w, &args, 1);
+    XtGetValues(w, args, XtNumber(args));
+    ret_h = h0 + 2 * h1 + 2 * h2;
     TRACE_GUI((stderr, "xm_get_height: %d", ret_h));
     return ret_h;
 }
