@@ -185,6 +185,12 @@ typedef unsigned long xuint32;
 # endif
 #endif
 
+#if defined(HAVE_STDINT_H)
+#include <stdint.h>
+#elif defined(HAVE_INTTYPES_H)
+#include <inttypes.h>
+#endif
+
 /* for unused parameters */
 #ifndef UNUSED
 #define UNUSED(x) ((void)(x))
@@ -1008,7 +1014,6 @@ extern int bbox_voffset;
 #endif
 
 /* globals from statusline.h */
-extern int global_statusline_h; /* height of statusline, or 0 */
 extern Widget statusline;
 
 
